@@ -2,8 +2,8 @@ from python_search.apps.window_manager import WindowManager
 from python_search.entries_group import EntriesGroup
 from python_search.environment import is_mac
 from python_search.shortcut.gnome import Gnome
-from python_search.shortcut.i3 import I3
 from python_search.shortcut.mac import Mac
+from python_search.shortcut.xfce import XFCE
 
 
 class ShortcutGenerator:
@@ -15,7 +15,7 @@ class ShortcutGenerator:
         self.configuration = configuration
         self.mac = Mac(self.configuration)
         self.gnome = Gnome(self.configuration)
-        self.i3 = I3(self.configuration)
+        self.xfce = XFCE(self.configuration)
 
     def configure(self):
         if is_mac():
@@ -26,6 +26,6 @@ class ShortcutGenerator:
             self.gnome.generate()
             return
 
-        if WindowManager.is_i3():
-            self.i3.generate()
+        if WindowManager.is_xfce():
+            self.xfce.generate()
             return
